@@ -130,13 +130,13 @@ def _process_element(e, clean, literals) -> Node:
                 if re.search("^[ \xA0]+$", e.text):
                     node.content = e.text
                 else:
-                    node.content = None if e.text.strip() == '' else e.text.strip()
+                    node.content = None if e.text.strip() == '' else " ".join(e.text.split())
         if e.tail is not None:
             # if tail consists entirely of one or more spaces and/or non-breaking spaces, keep it
             if re.search("^[ \xA0]+$", e.tail):
                 node.tail = e.tail
             else:
-                node.tail = None if e.tail.strip() == '' else e.tail.strip()
+                node.tail = None if e.tail.strip() == '' else " ".join(e.tail.split())
     else:
         node.content = e.text
         node.tail = e.tail
@@ -271,15 +271,16 @@ def to_xml(node: Node, parent: Node = None, level: int = 0) -> str:
 
     if parent is None:
         if len(node.nsmap) > 0:
-            attributes += " " + " ".join([f"xmlns:{k}=\"{v}\"" for k, v in node.nsmap.items()])
+            attributes += " ".join([f"xmlns:{k}=\"{v}\"" for k, v in node.nsmap.items()])
     elif node.nsmap != parent.nsmap:
         nsmap = _nsp_unique(node.nsmap, parent.nsmap)
-        attributes += " " + " ".join([f"xmlns:{k}=\"{v}\"" for k, v in nsmap.items()])
+        attributes += " ".join([f"xmlns:{k}=\"{v}\"" for k, v in nsmap.items()])
 
     if len(node.extras) > 0:
-        attributes += " " + " ".join([f"{k}=\"{v}\"" for k, v in node.extras.items()])
+        attributes += " ".join([f"{k}=\"{v}\"" for k, v in node.extras.items()])
 
     if len(attributes) > 0:
+        # Add final prefix-space to attribute string
         attributes = " " + attributes
 
     if node.content is not None:
